package de.hft.stuttgart.citydoctor2.webservice.endpoints;

import java.util.ArrayList;
import java.util.List;

import javax.ws.rs.GET;
import javax.ws.rs.Path;
import javax.ws.rs.Produces;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Response;

import de.hft.stuttgart.citydoctor2.check.DefaultParameter;
import de.hft.stuttgart.citydoctor2.check.Requirement;
import de.hft.stuttgart.citydoctor2.check.RequirementType;
import de.hft.stuttgart.citydoctor2.checks.CheckPrototype;
import de.hft.stuttgart.citydoctor2.checks.Checks;
import de.hft.stuttgart.citydoctor2.webservice.model.AvailableChecksReturnType;
import de.hft.stuttgart.citydoctor2.webservice.model.CheckReturnType;

@Path("checks")
public class ChecksEndpoint {
	
	private AvailableChecksReturnType returnValue;
	
	public ChecksEndpoint() {
		returnValue = new AvailableChecksReturnType();
		List<CheckReturnType> geometricChecks = new ArrayList<>();
		List<CheckReturnType> semanticChecks = new ArrayList<>();
		returnValue.setGeometricChecks(geometricChecks);
		returnValue.setSemanticChecks(semanticChecks);
		
		List<CheckPrototype> prototypes = Checks.getCheckPrototypes();
		for (CheckPrototype prototype : prototypes) {
			CheckReturnType returnVal = new CheckReturnType();
			returnVal.setName(prototype.getCheckId().toString());
			List<DefaultParameter> defaultParameters = new ArrayList<>();
			for (Requirement req : prototype.checksRequirements()) {
				defaultParameters.addAll(req.getDefaultParameter());
			}
			returnVal.setParameters(defaultParameters);
			if (prototype.getType() == RequirementType.GEOMETRY) {
				geometricChecks.add(returnVal);
			} else if (prototype.getType() == RequirementType.SEMANTIC) {
				semanticChecks.add(returnVal);
			} else {
				throw new IllegalStateException("Cannot handle check type: " + prototype.getType());
			}
		}
	}
	
	@GET
	@Produces(MediaType.APPLICATION_JSON)
	public Response getChecks() {
		return Response.ok(returnValue).build();
	}

}
